#pyuic4 icon.ui -o icon.py
##pyuic4 analogScope.ui -o analogScope.py
#pyuic4 digitalScope.ui -o digitalScope.py
#pyuic4 aboutDevice.ui -o aboutDevice.py
#pyuic4 transistorCE.ui -o transistorCE.py
#pyuic4 sensorTemplate.ui -o sensorTemplate.py
#pyuic4 rodpendulum.ui -o rodpendulum.py
#pyuic4 wirelessTemplate.ui -o wirelessTemplate.py
#pyuic4 diodeIV.ui -o diodeIV.py
#pyuic4 rectifier.ui -o rectifier.py
#pyuic4 template_transient.ui -o template_transient.py
#pyuic4 template_graph.ui -o template_graph.py
#pyuic4 template_xc.ui -o template_xc.py
#pyuic4 template_xl.ui -o template_xl.py
#pyuic4 template_bandpass.ui -o template_bandpass.py
#pyuic4 arbitStream.ui -o arbitStream.py
#pyuic4 single_col_exp.ui -o single_col_exp.py
#pyuic4 controlWidgets.ui -o controlWidgets.py
#pyuic4 simplePendulum.ui -o simplePendulum.py
#pyuic4 sensorGrid.ui -o sensorGrid.py
#pyuic4 loadSineTable.ui -o loadSineTable.py
#pyuic4 NFC.ui -o NFC.py
#pyuic4 calibration_loader.ui -o calibration_loader.py
#pyuic4 calibrator.ui -o calibrator.py
#pyuic4 dsm501.ui -o dsm501.py
#pyuic4 remote.ui -o remote.py
#
cd widgets/
#pyuic4 dial.ui -o dial.py 
#pyuic4 dialAndDoubleSpin.ui -o dialAndDoubleSpin.py 
#pyuic4 pulseCounter.ui -o pulseCounter.py 
#pyuic4 button.ui -o button.py
#pyuic4 sensorWidget.ui -o sensorWidget.py
#pyuic4 selectAndButton.ui -o selectAndButton.py
#pyuic4 spinBox.ui -o spinBox.py
#pyuic4 doubleSpinBox.ui -o doubleSpinBox.py
#pyuic4 sineWidget.ui -o sineWidget.py
pyuic4 pwmWidget.ui -o pwmWidget.py
#pyuic4 supplyWidget.ui -o supplyWidget.py
#pyuic4 setStateList.ui -o setStateList.py
cd ..
